==> impl-0.1.0-sources.jar: delombok/io/github/qsy7/ssh/executor/ExpectSSHCommandExecutor.java <==
package io.github.qsy7.ssh.executor;

import io.github.qsy7.property.impl.annotation.Property;
import io.github.qsy7.ssh.AbstractSSHService;
import io.github.qsy7.ssh.api.SSHPublicKeyPath;
import io.github.qsy7.ssh.api.model.command.SSHExpectCommand;
import java.io.IOException;
import java.lang.reflect.InvocationTargetException;
import net.schmizz.sshj.SSHClient;
import net.schmizz.sshj.connection.channel.direct.Session;

// @Component
public class ExpectSSHCommandExecutor extends AbstractSSHService<SSHExpectCommand> {
  public ExpectSSHCommandExecutor(
      @Property(SSHPublicKeyPath.class) final String sshPublicKeyPath, SSHExpectCommand command) {
    super(sshPublicKeyPath, command);
  }

  @Override
  protected void doExecute(SSHClient sshClient, Session session)
      throws IOException, ClassNotFoundException, NoSuchMethodException, IllegalAccessException,
          InvocationTargetException, InstantiationException {
    // @NOTE: deprecated for now
    //
    //    CommandExecutionResult shellCommand = new CommandExecutionResult();
    //    sshCommand.setShellCommand(shellCommand);
    //    try (final Session.Shell shell = session.startShell()) {
    //      try (final Expect expect =
    //          CommandExecutionUtil.setupExpectHandler(
    //              applicationEventPublisher,
    //              shellCommand,
    //              sshCommand.getTimeout(),
    //              shell.getInputStream(),
    //              shell.getErrorStream(),
    //              shell.getOutputStream())) {
    //        //expect.sendLine(sshCommand.getCommandLine());
    //        //    SSHExpectScript sshExpectScript =
    //        //        (SSHExpectScript)
    //        //            Class.forName(sshCommand.getCommandExecutionClassName())
    //        //                .getConstructor(SSHClient.class, Session.class)
    //        //                .newInstance(/*sshClient, */ session);
    //        //    sshExpectScript.run();
    //
    //        CommandExecutionUtil.setReturnCode(expect, shellCommand);
    //      }
    //    }
  }
}

==> impl-0.3.3-sources.jar: delombok/io/github/qsy7/ssh/executor/ExpectSSHCommandExecutor.java <==
package io.github.qsy7.ssh.executor;

import io.github.qsy7.property.api.annotation.Property;
import io.github.qsy7.ssh.AbstractSSHService;
import io.github.qsy7.ssh.api.SSHPublicKeyPath;
import io.github.qsy7.ssh.api.model.command.SSHExpectCommand;
import net.schmizz.sshj.SSHClient;
import net.schmizz.sshj.connection.channel.direct.Session;

// @Component
public class ExpectSSHCommandExecutor extends AbstractSSHService<SSHExpectCommand> {
  public ExpectSSHCommandExecutor(
      @Property(SSHPublicKeyPath.class) final String sshPublicKeyPath, SSHExpectCommand command) {
    super(sshPublicKeyPath, command);
  }

  @Override
  protected void doExecute(SSHClient sshClient, Session session) {
    // @NOTE: deprecated for now
    //
    //    CommandExecutionResult shellCommand = new CommandExecutionResult();
    //    sshCommand.setShellCommand(shellCommand);
    //    try (final Session.Shell shell = session.startShell()) {
    //      try (final Expect expect =
    //          CommandExecutionUtil.setupExpectHandler(
    //              applicationEventPublisher,
    //              shellCommand,
    //              sshCommand.getTimeout(),
    //              shell.getInputStream(),
    //              shell.getErrorStream(),
    //              shell.getOutputStream())) {
    //        //expect.sendLine(sshCommand.getCommandLine());
    //        //    SSHExpectScript sshExpectScript =
    //        //        (SSHExpectScript)
    //        //            Class.forName(sshCommand.getCommandExecutionClassName())
    //        //                .getConstructor(SSHClient.class, Session.class)
    //        //                .newInstance(/*sshClient, */ session);
    //        //    sshExpectScript.run();
    //
    //        CommandExecutionUtil.setReturnCode(expect, shellCommand);
    //      }
    //    }
  }
}
